@@ -9,10 +9,9 @@ import StringIO
 import base64
 import httplib
 import urllib2
-import cgi
 import re
 
-__version__  = '0.10.2'
+__version__  = '0.10.3'
 __author__ = "Hiroki Ohtani (liris.pp@gmail.com)"
 __contributors__ = ["Junji NAKANISHI <daemonfreaks@gmail.com>"]
 __copyright__ = "Copyright (c) 2006 Hiroki Ohtani"
@@ -1036,7 +1035,7 @@ def _condToQuery(cond, depth, wwidth, hwidth, awidth):
 def _escape(s):
     if type(s) == unicode:
         s = s.encode("utf-8")
-    return cgi.escape(s)
+    return urllib2.quote(s)
 
 
 def _enc(s):
